@@ -201,7 +201,7 @@ PmPutRow(RowBuf,numComp,numCol,Pt)
     MCU *RowBuf;
     int numCol,Pt;
 {
-  register int col,v;
+  int col,v;
     
   /*
    * Mulitply 2^Pt before output. Pt is the point
@@ -240,7 +240,7 @@ PmPutRow(RowBuf,numComp,numCol,Pt)
  *--------------------------------------------------------------
  */
 #define PmPutRow(RowBuf,numComp,numCol,Pt) 				\
-{ register int col,v;							\
+{ int col,v;							\
   if (numComp==1) { /*pgm*/						\
      for (col = 0; col < numCol; col++) {				\
          v=RowBuf[col][0]<<Pt;						\
@@ -479,9 +479,9 @@ void DecodeFirstRow(dcPtr,curRowBuf)
     DecompressInfo *dcPtr;
     MCU *curRowBuf;
 {
-    register short curComp,ci;
-    register int s,col,compsInScan,numCOL;
-    register JpegComponentInfo *compptr;
+    short curComp,ci;
+    int s,col,compsInScan,numCOL;
+    JpegComponentInfo *compptr;
     int Pr,Pt,d;
     HuffmanTable *dctbl;
 
@@ -568,8 +568,8 @@ void
 DecodeImage(dcPtr)
     DecompressInfo *dcPtr;
 {
-    register int s,d,col,row;
-    register short curComp, ci;
+    int s,d,col,row;
+    short curComp, ci;
     HuffmanTable *dctbl;
     JpegComponentInfo *compptr;
     int predictor;
